@@ -1,6 +1,6 @@
 #ifndef GCC_TM_H
 #define GCC_TM_H
-#define TARGET_CPU_DEFAULT (TARGET_CPU_arm926ejs)
+#define TARGET_CPU_DEFAULT ("arm926ej-s")
 #ifndef LIBC_GLIBC
 # define LIBC_GLIBC 1
 #endif
@@ -44,8 +44,5 @@
 #if defined IN_GCC && !defined GENERATOR_FILE
 # include "insn-modes.h"
 #endif
-#if defined IN_GCC && defined GENERATOR_FILE && !defined BITS_PER_UNIT
-#include "machmode.h"
-#endif
 # include "defaults.h"
 #endif /* GCC_TM_H */
